#!/bin/sh

###############################################################################
#                                                                             #
# This script is part of the FeeCommunication Software for the DCS (TPC, TRD) #
# of the ALICE experiment at CERN. It starts the FeeServer and takes care of  #
# updating and restarting commands. It ends only , when the FeeServer is      #
# terminated (which way soever) and no updateFeeServer or restartFeeServer    #
# command has triggered the termination.                                      #
#                                                                             #
# @author: S. Bablok, C. Kofler (ZTT FH Worms)                                #
# (for more information: http://www.ztt.fh-worms.de)                          #
#                                                                             #
###############################################################################

# this is nice but not applicable for the DCS board, since the mounted
# network disk might have different paths on the build machine and the board
# prefix=/home/dcs
# exec_prefix=${prefix}
# bindir=${exec_prefix}/bin
# sbindir=${exec_prefix}/sbin
bindir=`dirname $0`

echo " "

if [ $1 ]
then
	echo "setting new FEE_SERVER_NAME $1"
	export FEE_SERVER_NAME=$1
fi

echo "updating time on board"
# including Timeserver name
if [ -r /etc/network ]
then
	. /etc/network
fi

# check that we have `rdate' 
if test ! `which rdate > /dev/null 2>&1` ; then 
    IP_TIMESERVER=
fi

# Check if we have a time server 
if test ! "x$IP_TIMESERVER" = "x"
then
	# retrieving current date and time
	rdate $IP_TIMESERVER
else
	echo "no timeserver specified"
fi

echo " "
echo "starting FeeServer $FEE_SERVER_NAME"
echo "  Have fun ;-)"
date

doRestart=1

while [ $doRestart -ne 0 ]
do

	$bindir/feeserver
	retVal=$?

	while [ $retVal -eq 3 ] || [ $retVal -eq 2 ]
	do
		#echo "Exit status of FeeServer: $retVal"

		sleep 1
		echo "killing all feeserver processes to prepare restart"
		killall -q -KILL feeserver
		echo " "

		# prepare update only if "newFeeServer" exists and is non-zero
		if [ $retVal -eq 3 ] && [ -s newFeeserver ]
		then
			echo "preparing new binary for update"
			mv feeserver feeserver.org
			mv newFeeserver feeserver
			chmod 777 feeserver
			echo "FeeServer update finalised"
		fi

		echo " "
		if [ $IP_TIMESERVER ]
		then
			echo "updating time on board"
			# retrieving current date and time
			rdate $IP_TIMESERVER
		fi

		echo "restarting FeeServer..."
		echo " "
		$bindir/feeserver
		retVal=$?

	done
	echo "FeeServer exited with status $retVal."

	if [ $retVal -eq 0 ]
	then
		echo "Clean exit"
		doRestart=0
	elif [ $retVal -eq 201 ]
	then
		echo "Insufficient memory!"
		doRestart=0
	elif [ $retVal -eq 202 ]
	then
		echo "No FeeServer name specified!"
		doRestart=0
	elif [ $retVal -eq 203 ]
	then
		echo "No DIM_DNS_NODE specified!"
		doRestart=0
	elif [ $retVal -eq 204 ]
	then
		echo "DIM framework exited FeeServer"
		echo "(maybe Server with same name already exists)."
		doRestart=0
	elif [ $retVal -eq 205 ]
	then
		echo "Unable to run as DIM Server"
		doRestart=0
	else
		echo "FeeServer exited due to unknow error!"
		echo "Trying to restart FeeServer now ..."
		echo ""
	fi

done

echo " -- BYE --"
echo " "

